require "#{File.dirname(__FILE__)}/../lib/spec_helper.rb"

def set_search_values(form, fact, comparator, value)
  form.all('input[name="search_params[][fact]"]').last.set(fact)
  form.all('select[name="search_params[][comparator]"]').last.find("option[value='#{comparator}']").select_option
  form.all('input[name="search_params[][value]"]').last.set(value)
end

describe 'The Dashboard' do

  let(:search_form) { session.find('#search_params') }

  before :all do
    visit_dashboard

    session.should have_css("#content", :visible => true)
  end

  after :all do
    logout
  end

  it 'should have an inventory search link' do
    session.should have_css('div#header a', :text => 'Inventory Search')
  end

  describe 'inventory search' do

    before :all do
      select_inventory_search
    end

    describe 'search form' do

      before :all do
        # reset the search form
        select_inventory_search
      end

      after :all do
        select_inventory_search
      end

      it 'should allow you to add a new set of fields' do
        search_form.all('div.fact_search_params').count.should == 1

        search_form.find('a.add').click

        search_form.all('div.fact_search_params').count.should == 2
      end

      it 'extra search fields should be created without content' do

        set_search_values(search_form, 'a fact', 'ne', 'a value')

        search_form.find('a.add').click

        search_form.all('input[name="search_params[][fact]"]').last.value.should == ''
        search_form.all('select[name="search_params[][comparator]"]').last.find('option[value="eq"]').selected?.should be_true
        search_form.all('input[name="search_params[][value]"]').last.value.should == ''
      end

    end

    it 'should allow you do to a simple inventory search' do
      # search for a fact that can't exist, which means all nodes should be returned
      set_search_values(search_form, 'operatingsystem', 'ne', 'madeupos')

      search_form.click_button('search_button')

      # a Nodes table should appear
      session.should have_css('div.section table.main')
    end

    it 'should show an error on an invalid inventory search' do
      set_search_values(search_form, 'a', 'lt', 'b')

      search_form.click_button('search_button')

      session.should have_css('#inventory_error')
    end

  end

end
